/*
 * This file is a part of VyQChat.
 *
 * Copyright (C) 2002-2004 Pawel Stolowski <yogin@linux.bydg.org>
 *
 * VyQChat is free software; you can redestribute it and/or modify it
 * under terms of GNU General Public License by Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY. See GPL for more details.
 */

#ifndef __SETTINGS_H
#define __SETTINGS_H

#include "sound.h"
#include "vypacket.h"
#include <qstring.h>
#include <qcolor.h>

class QSettings;
class SettingsDialog;

class Settings
{
	private:
		QString nick, def_nick;
		QString hostname, def_hostname;
		QString ip, def_ip;
		QString broadcast, def_broadcast;
		QString topic, def_topic;
		Sound::SoundType def_sound;
		int status;  //status on exit
		int refresh;
		QColor special_color;
		QColor normal_color;
		QColor own_color;
		int x, y, width, height, listwidth;
		Sound::SoundType sound;
		QString playcmd;
		QString snd[Sound::Dummy];
		bool sndp[Sound::Dummy]; //play-dont play flags
		QString def_snd[Sound::Dummy];
		QString def_playcmd;
		bool confirm_exit;
		bool hide_channels;
		bool regexp_on;
		bool toolbar_on;
		bool userslist_on;
		bool nickcombo_on;
		bool popup;
		bool nopopup_dnd;
		bool keep_status; //if last status should be restored on startup
		QString encoding;
		QString version; //vyqchat version for detecting older config file

	public:
		Settings();
		~Settings();
		bool getDefaults();
		bool load(QSettings *cfg);
		bool save(QSettings *cfg);
	
		friend class MainWindow;
		friend class SettingsDialog;
		friend class Sound;
		friend class SoundSystem;
		friend class SoundArts;
		friend class SoundLibAo;
		friend class SoundCommand;
};


#endif

