/*
 * This file is a part of VyQChat.
 *
 * Copyright (C) 2002-2004 Pawel Stolowski <yogin@linux.bydg.org>
 *
 * VyQChat is free software; you can redestribute it and/or modify it
 * under terms of GNU General Public License by Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY. See GPL for more details.
 */

#ifndef __SETTINGSDLG_H
#define __SETTINGSDLG_H

#include <qtabdialog.h>
#include "settings.h"

class QListBox;
class QLineEdit;
class QCheckBox;
class QComboBox;
class QSpinBox;
class QVButtonGroup;

class SettingsDialog: public QTabDialog
{
	Q_OBJECT

	private slots:
		void slotApply();
		void slotDefaults();
		void slotPopupCheckBoxChanged(bool state);
		void slotSoundEventSelected(int index);
		void slotBrowseSoundClicked();
		void slotSoundSystemClicked(int index);
		void slotPlayFlagClicked(bool state);
		
	private:
		QLineEdit *le_nick, *le_hostname, *le_ip, *le_broadcast, *le_sndname,
			*le_playcmd;
		QSpinBox *sp_refresh;
		QVButtonGroup *opt_snddev;
		QCheckBox *b_hide, *b_popup, *b_popupdnd, *b_play, *b_confirmexit;
		QListBox *snd_list;
		QComboBox *l_enc;
		Settings settings;  //copy of settings for manipulation
		Settings *currsettings; //current application settings
		
		void setupNetworkTab(QWidget *p);
		void setupSoundDeviceTab(QWidget *p);
		void setupSoundsTab(QWidget *p);
		void setupLookTab(QWidget *p);
		void setupMiscTab(QWidget *p);

	public:
		SettingsDialog(QWidget *parent, Settings *s);
		~SettingsDialog();
};

#endif

